index.CN:
Grab Real-Time Stock Index Information in China Market
Description
With `index.CN` function, users can obtain the real-time information about the stock index in China market, including Shanghai Stock Exchange (SSE) and Shenzhen Stock Exchange (SZSE).
Usage
index.CN(exchange)
Arguments
exchange
The stock exchange.
Available options include "sh" and "sz" for Shanghai Stock Exchange and Shenzhen Stock Exchange, respectively.
Value
index
The name of the index
index.value
The current value of the index
change
The change of the index within the day
change.percentage
The percentage of the corresponding change.If the value here is 0.07, then the change is 0.07%.
volume.hand
The volume tranded within the day.Please note that the unit here is "hand", that is 100 stocks. This is a commonly used unit in China Market.
amount.10k
The amount within the day.Please note that here the unit is 10k Chinese Yuan. That is, if the amount here is 1, then the actual amount is 10,000 Chinese Yuan.
Details
There are two stock exchanges in China, Shanghai Stock Exchange (SSE) and Shenzhen Stock Exchange (SZSE). The trading hours are 9:30 to 11:30, and 13:00 to 15:00 (Beijing time, i.e. UTC+08:00), Monday to Friday, excluding public holidays in China).